# Changelog

All notable changes to this project will be documented in this file.

## [0.2.1] - 2024-12-17

### ⚙️ Miscellaneous Tasks

- Fix semantic release workflow by adding actions write permission (#95)

<!-- generated by git-cliff -->
